@@ -21,7 +21,7 @@ from humanfriendly import format_size
 
 
 __author__ = 'Erik Moqvist'
-__version__ = '16.8.0'
+__version__ = '16.9.1'
 
 
 DEFAULT_WORD_SIZE_BITS = 8
@@ -283,6 +283,21 @@ def pretty_ihex(record):
             + '\033[0m' + type_text)
 
 
+def pretty_ti_txt(line):
+    """Make given TI TXT line pretty by adding colors to it.
+
+    """
+
+    if line.startswith('@'):
+        line = '\033[0;33m' + line + '\033[0m (segment address)'
+    elif line == 'q':
+        line = '\033[0;35m' + line + '\033[0m (end of file)'
+    else:
+        line += ' (data)'
+
+    return line
+
+
 def is_srec(records):
     try:
         unpack_srec(records.partition('\n')[0].rstrip())
@@ -748,7 +763,8 @@ class BinFile(object):
 
     @property
     def maximum_address(self):
-        """The maximum address of the data, or ``None`` if the file is empty.
+        """The maximum address of the data plus one, or ``None`` if the file
+        is empty.
 
         """
 
@@ -1235,12 +1251,12 @@ class BinFile(object):
         """Return a byte string of all data within given address range.
 
         `minimum_address` is the absolute minimum address of the
-        resulting binary data. By default this is the minimum address
-        in the binary.
+        resulting binary data (including). By default this is the
+        minimum address in the binary.
 
         `maximum_address` is the absolute maximum address of the
-        resulting binary data (non-inclusive). By default this is the
-        maximum address in the binary.
+        resulting binary data (excluding). By default this is the
+        maximum address in the binary plus one.
 
         `padding` is the word value of the padding between
         non-adjacent segments. Give as a bytes object of length 1 when
@@ -1709,6 +1725,8 @@ def _do_pretty(args):
         print('\n'.join([pretty_srec(line) for line in data.splitlines()]))
     elif is_ihex(data):
         print('\n'.join([pretty_ihex(line) for line in data.splitlines()]))
+    elif is_ti_txt(data):
+        print('\n'.join([pretty_ti_txt(line) for line in data.splitlines()]))
     else:
         raise UnsupportedFileFormatError()
 
