@@ -1418,15 +1418,17 @@ Data ranges:
         self._test_command_line_ok_bytes(command, binfile.as_binary())
 
     def test_command_line_pretty(self):
-        datas = [
+        pretty_files = [
             'tests/files/convert.pretty.s19',
             'tests/files/empty_main.pretty.hex',
             'tests/files/empty_main.pretty.s19',
+            'tests/files/empty_main.pretty.hex.txt',
             'tests/files/in.pretty.hex',
-            'tests/files/in.pretty.s19'
+            'tests/files/in.pretty.s19',
+            'tests/files/in.pretty.hex.txt'
         ]
 
-        for pretty_file in datas:
+        for pretty_file in pretty_files:
             with open(pretty_file, 'r') as fin:
                 expected_output = fin.read()
 
